@@ -73,6 +73,7 @@ public:
 
     calc=new Calc();
     calc->SetFlex(true,true);
+    plugins.push_back(calc);
 
     tab->Add(L"Calc",calc);
 
@@ -108,6 +109,12 @@ public:
     menu
       ->AddMenuItemSub(_ld(menuProject))
         ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(L"Settings")
+        ->AddMenuItemSub(L"Calculator")
+          ->AddMenuItemRadio(L"_Degree",Lum::OS::qualifierControl,L"d",calcTrigoMode,0)
+          ->AddMenuItemRadio(L"_Radiant",Lum::OS::qualifierControl,L"r",calcTrigoMode,1);
+
     menu
       ->AddMenuItemSub(_ld(menuHelp))
         ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
