@@ -312,6 +312,8 @@ Parser::Parser()
   AddFunction("sinh",Sinh,OP4);
   AddFunction("cosh",Cosh,OP4);
   AddFunction("tanh",Tanh,OP4);
+  AddFunction("asinh",ASinh,OP4);
+  AddFunction("acosh",ACosh,OP4);
   AddFunction("atanh",ATanh,OP4);
   AddFunction("exp",Etox,OP4);
 //  AddFunction("log",Log,OP4);
